@@ -849,7 +849,7 @@ void File_Aac::AudioSpecificConfig_OutOfBand (int64s sampling_frequency_, int8u
         Infos["ChannelPositions/String2"].From_UTF8(Aac_ChannelConfiguration2_GetString(channelConfiguration));
         Infos["ChannelLayout"].From_UTF8(Aac_ChannelLayout_GetString(channelConfiguration));
     }
-    else if (audioObjectType_==42 && !Conf.WaitForNextIndependantFrame && Conf.numOutChannels)
+    else if (audioObjectType_==42 && Conf.IFrameParsed && Conf.numOutChannels)
     {
         Infos["Channel(s)"].From_Number(Conf.numOutChannels);
     }
