@@ -42,6 +42,7 @@ namespace MediaInfoLib
 //***************************************************************************
 
 File_ChannelGrouping::File_ChannelGrouping()
+:File_Pcm_Base()
 {
     //Configuration
     #if MEDIAINFO_EVENTS
@@ -59,7 +60,6 @@ File_ChannelGrouping::File_ChannelGrouping()
     //In
     BitDepth=0;
     SamplingRate=0;
-    Endianness=0;
     Aligned=false;
     CanBePcm=false;
     Common=NULL;
@@ -135,7 +135,7 @@ void File_ChannelGrouping::Read_Buffer_Init()
         //SMPTE ST 337
         {
             File_SmpteSt0337* Parser=new File_SmpteSt0337;
-            Parser->Container_Bits=BitDepth;
+            Parser->BitDepth=BitDepth;
             Parser->Endianness=Endianness;
             Parser->Aligned=Aligned;
             Common->Parsers.push_back(Parser);
