@@ -224,6 +224,9 @@
 #if defined(MEDIAINFO_DTSUHD_YES)
     #include "MediaInfo/Audio/File_DtsUhd.h"
 #endif
+#if defined(MEDIAINFO_DAT_YES)
+    #include "MediaInfo/Audio/File_Dat.h"
+#endif
 #if defined(MEDIAINFO_DOLBYE_YES)
     #include "MediaInfo/Audio/File_DolbyE.h"
 #endif
@@ -348,6 +351,12 @@
     #include "MediaInfo/Image/File_Tga.h"
 #endif
 
+//---------------------------------------------------------------------------
+// Tag
+#if defined(MEDIAINFO_ICC_YES)
+    #include "MediaInfo/Tag/File_Icc.h"
+#endif
+
 //---------------------------------------------------------------------------
 // Archive
 #if defined(MEDIAINFO_7Z_YES)
@@ -432,10 +441,9 @@ File__MultipleParsing::File__MultipleParsing()
         {File_MpegTs* Temp=new File_MpegTs(); Temp->BDAV_Size=4; Parser.push_back(Temp);}
         {File_MpegTs* Temp=new File_MpegTs(); Temp->BDAV_Size=4; Temp->NoPatPmt=true; Parser.push_back(Temp);}
     #endif
-//    Only with directories, no By Buffer interface
-//    #if defined(MEDIAINFO_BDMV_YES)
-//        Parser.push_back(new File_Bdmv());
-//    #endif
+    #if defined(MEDIAINFO_BDMV_YES)
+        Parser.push_back(new File_Bdmv());
+    #endif
     #if defined(MEDIAINFO_CDXA_YES)
         Parser.push_back(new File_Cdxa());
     #endif
@@ -566,9 +574,6 @@ File__MultipleParsing::File__MultipleParsing()
     #if defined(MEDIAINFO_FLIC_YES)
         Parser.push_back(new File_Flic());
     #endif
-    #if defined(MEDIAINFO_H263_YES)
-        Parser.push_back(new File_H263());
-    #endif
     #if defined(MEDIAINFO_MPEG4V_YES)
         Parser.push_back(new File_Mpeg4v());
     #endif
@@ -635,6 +640,10 @@ File__MultipleParsing::File__MultipleParsing()
         Parser.push_back(new File_DtsUhd());
     #endif
 //    Too many false-positives
+//    #if defined(MEDIAINFO_DAT_YES)
+//        Parser.push_back(new File_Dat());
+//    #endif
+//    Too many false-positives
 //    #if defined(MEDIAINFO_DOLBYE_YES)
 //        Parser.push_back(new File_DolbyE());
 //    #endif
@@ -659,9 +668,6 @@ File__MultipleParsing::File__MultipleParsing()
     #if defined(MEDIAINFO_MPCSV8_YES)
         Parser.push_back(new File_MpcSv8());
     #endif
-    #if defined(MEDIAINFO_MPEGA_YES)
-        Parser.push_back(new File_Mpega());
-    #endif
     #if defined(MEDIAINFO_OPENMG_YES)
         Parser.push_back(new File_OpenMG());
     #endif
@@ -751,9 +757,6 @@ File__MultipleParsing::File__MultipleParsing()
     #if defined(MEDIAINFO_TIFF_YES)
         Parser.push_back(new File_Tiff());
     #endif
-    #if defined(MEDIAINFO_TGA_YES)
-        Parser.push_back(new File_Tga());
-    #endif
 
     // Archive
     #if defined(MEDIAINFO_7Z_YES)
@@ -791,6 +794,20 @@ File__MultipleParsing::File__MultipleParsing()
     #if defined(MEDIAINFO_OTHER_YES)
         Parser.push_back(new File_Other());
     #endif
+
+    //At the end, too much sensible
+    #if defined(MEDIAINFO_MPEGA_YES)
+        Parser.push_back(new File_Mpega());
+    #endif
+    #if defined(MEDIAINFO_TGA_YES)
+        Parser.push_back(new File_Tga());
+    #endif
+    #if defined(MEDIAINFO_H263_YES)
+        Parser.push_back(new File_H263());
+    #endif
+    #if defined(MEDIAINFO_ICC_YES)
+        Parser.push_back(new File_Icc());
+    #endif
 }
 
 //---------------------------------------------------------------------------
@@ -800,22 +817,6 @@ File__MultipleParsing::~File__MultipleParsing()
         delete Parser[Pos]; //Parser[Pos]=NULL
 }
 
-//***************************************************************************
-// Streams management
-//***************************************************************************
-
-//---------------------------------------------------------------------------
-void File__MultipleParsing::Streams_Finish()
-{
-    if (Parser.size()!=1)
-        return;
-
-    Parser[0]->Open_Buffer_Finalize();
-    #if MEDIAINFO_TRACE
-        Details=Parser[0]->Details;
-    #endif //MEDIAINFO_TRACE
-}
-
 //***************************************************************************
 // Buffer - Global
 //***************************************************************************
@@ -848,6 +849,10 @@ void File__MultipleParsing::Read_Buffer_Unsynched()
 //---------------------------------------------------------------------------
 void File__MultipleParsing::Read_Buffer_Continue()
 {
+    //Position if requested (reset of value after it was set in the previous call)
+    if (Parser.size()==1 && Parser[0]->File_GoTo!=(int64u)-1)
+        Parser[0]->File_GoTo=File_GoTo;
+
     //Parsing
     for (size_t Pos=0; Pos<Parser.size(); Pos++)
     {
@@ -862,12 +867,6 @@ void File__MultipleParsing::Read_Buffer_Continue()
             delete Parser[Pos];
             Parser.erase(Parser.begin()+Pos);
             Pos--; //for the next position
-
-            if (Parser.empty())
-            {
-                File__Analyze* Temp=new File_Unknown(); Parser.push_back(Temp);
-                Read_Buffer_Init();
-            }
         }
         else
         {
@@ -887,17 +886,22 @@ void File__MultipleParsing::Read_Buffer_Continue()
             {
                 //Status
                 if (!Status[IsAccepted] && Parser[Pos]->Status[IsAccepted])
-                    Status[IsAccepted]=true;
+                    Accept();
                 if (!Status[IsFilled] && Parser[Pos]->Status[IsFilled])
-                    Status[IsFilled]=true;
+                    Fill();
                 if (!Status[IsUpdated] && Parser[Pos]->Status[IsUpdated])
-                    Status[IsUpdated]=true;
+                    Update();
                 if (!Status[IsFinished] && Parser[Pos]->Status[IsFinished])
-                    Status[IsFinished]=true;
+                    Finish();
 
-                //Positionning if requested
-                if (Parser[0]->File_GoTo!=(int64u)-1)
-                   File_GoTo=Parser[0]->File_GoTo;
+                //Seek if requested
+                if (Parser[0]->File_GoTo<File_Size)
+                    File_GoTo=Parser[0]->File_GoTo;
+                else if (Parser[0]->File_GoTo==File_Size && File_Size!=(int64u)-1)
+                {
+                    delete Parser[0];
+                    Parser.clear();
+                }
 
                 //Clean
                 #if MEDIAINFO_TRACE
@@ -906,6 +910,14 @@ void File__MultipleParsing::Read_Buffer_Continue()
             }
         }
     }
+
+    if (Parser.empty())
+    {
+        File__Analyze* Temp=new File_Unknown(); Parser.push_back(Temp);
+        Read_Buffer_Init();
+        Accept();
+        Finish();
+    }
 }
 
 } //NameSpace
