@@ -68,6 +68,30 @@ enum encryption_padding
 };
 #endif //MEDIAINFO_AES
 
+enum config_probe_type
+{
+    config_probe_none,
+    config_probe_size,
+    config_probe_dur,
+    config_probe_percent,
+};
+struct config_probe
+{
+    config_probe_type   Start_Type=config_probe_none;
+    config_probe_type   Duration_Type=config_probe_none;
+    int64u              Start=0;
+    int64u              Duration=0;
+    string              Parser;
+};
+
+enum display_captions
+{
+    DisplayCaptions_Command,
+    DisplayCaptions_Content,
+    DisplayCaptions_Stream,
+    DisplayCaptions_Max
+};
+
 //***************************************************************************
 // Class MediaInfo_Config_MediaInfo
 //***************************************************************************
@@ -371,10 +395,10 @@ public :
     void          File_Mmsh_Describe_Only_Set (bool NewValue);
     bool          File_Mmsh_Describe_Only_Get ();
     #endif //defined(MEDIAINFO_LIBMMS_YES)
-    void          File_Eia608_DisplayEmptyStream_Set (bool NewValue);
-    bool          File_Eia608_DisplayEmptyStream_Get ();
-    void          File_Eia708_DisplayEmptyStream_Set (bool NewValue);
-    bool          File_Eia708_DisplayEmptyStream_Get ();
+    Ztring        File_DisplayCaptions_Set (const Ztring& NewValue);
+    display_captions File_DisplayCaptions_Get ();
+    Ztring        File_ProbeCaption_Set(const Ztring& NewValue);
+    config_probe  File_ProbeCaption_Get(const string& Parser);
     #if defined(MEDIAINFO_AC3_YES)
     void          File_Ac3_IgnoreCrc_Set (bool NewValue);
     bool          File_Ac3_IgnoreCrc_Get ();
@@ -607,8 +631,9 @@ private :
     #if defined(MEDIAINFO_LIBMMS_YES)
     bool                    File_Mmsh_Describe_Only;
     #endif //defined(MEDIAINFO_LIBMMS_YES)
-    bool                    File_Eia608_DisplayEmptyStream;
-    bool                    File_Eia708_DisplayEmptyStream;
+    display_captions        DisplayCaptions;
+    std::vector<config_probe> File_ProbeCaption;
+    size_t                  File_ProbeCaption_Pos;
     #if defined(MEDIAINFO_AC3_YES)
     bool                    File_Ac3_IgnoreCrc;
     #endif //defined(MEDIAINFO_AC3_YES)
