@@ -240,6 +240,9 @@
 #if defined(MEDIAINFO_DTSUHD_YES)
     #include "MediaInfo/Audio/File_DtsUhd.h"
 #endif
+#if defined(MEDIAINFO_DAT_YES)
+    #include "MediaInfo/Audio/File_Dat.h"
+#endif
 #if defined(MEDIAINFO_DOLBYE_YES)
     #include "MediaInfo/Audio/File_DolbyE.h"
 #endif
@@ -644,6 +647,9 @@ static File__Analyze* SelectFromExtension(const String& Parser)
     #if defined(MEDIAINFO_DTSUHD_YES)
         if (Parser==__T("DtsUhd"))      return new File_DtsUhd();
     #endif
+    #if defined(MEDIAINFO_DAT_YES)
+        if (Parser==__T("Dat"))        return new File_Dat();
+    #endif
     #if defined(MEDIAINFO_DOLBYE_YES)
         if (Parser==__T("DolbyE"))      return new File_DolbyE();
     #endif
@@ -1052,6 +1058,9 @@ int MediaInfo_Internal::ListFormats(const String &File_Name)
     #if defined(MEDIAINFO_DTSUHD_YES)
         delete Info; Info=new File_DtsUhd();             if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
     #endif
+    #if defined(MEDIAINFO_DAT_YES)
+        delete Info; Info=new File_Dat();                if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
+    #endif
 //    Too many false-positives
 //    #if defined(MEDIAINFO_DOLBYE_YES)
 //        delete Info; Info=new File_DolbyE();             if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
@@ -1077,9 +1086,6 @@ int MediaInfo_Internal::ListFormats(const String &File_Name)
     #if defined(MEDIAINFO_MPCSV8_YES)
         delete Info; Info=new File_MpcSv8();             if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
     #endif
-    #if defined(MEDIAINFO_MPEGA_YES)
-        delete Info; Info=new File_Mpega();              if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
-    #endif
     #if defined(MEDIAINFO_OPENMG_YES)
         delete Info; Info=new File_OpenMG();             if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
     #endif
@@ -1210,6 +1216,9 @@ int MediaInfo_Internal::ListFormats(const String &File_Name)
     #endif
 
     //At the end, too much sensible
+    #if defined(MEDIAINFO_MPEGA_YES)
+        delete Info; Info=new File_Mpega();              if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
+    #endif
     #if defined(MEDIAINFO_TGA_YES)
         delete Info; Info=new File_Tga();                if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1; //At the end, too much sensible
     #endif
