@@ -64,6 +64,7 @@ namespace Elements
     const int32u AIFF_SSND=0x53534E44;
     const int32u AVI_=0x41564920;
     const int32u AVI__hdlr_strl_strh_txts=0x74787473;
+    const int32u BW64=0x42573634;
     const int32u FORM=0x464F524D;
     const int32u LIST=0x4C495354;
     const int32u MThd=0x4D546864;
@@ -158,6 +159,7 @@ File_Riff::File_Riff()
     IsBigEndian=false;
     IsWave64=false;
     IsRIFF64=false;
+    IsBW64=false;
     IsWaveBroken=false;
     IsNotWordAligned=false;
     IsNotWordAligned_Tested=false;
@@ -212,7 +214,7 @@ void File_Riff::Streams_Finish ()
 
     //Global
     if (IsRIFF64)
-        Fill(Stream_General, 0, General_Format_Profile, "RF64");
+        Fill(Stream_General, 0, General_Format_Profile, IsBW64?"BW64":"RF64");
     if (DolbyAudioMetadata) //Before ADM for having content before all ADM stuff
         Merge(*DolbyAudioMetadata, Stream_Audio, 0, 0);
     if (Adm)
@@ -311,20 +313,18 @@ void File_Riff::Streams_Finish ()
                 for (size_t Pos=0; Pos<Temp->second.Parsers[0]->Count_Get(StreamKind_Last); Pos++)
                 {
                     Ztring Temp_ID=ID;
-                    Ztring Temp_ID_String=ID;
                     Merge(*Temp->second.Parsers[0], StreamKind_Last, Pos, StreamPos_Base+Pos);
                     if (!Retrieve(StreamKind_Last, StreamPos_Last, General_ID).empty())
                     {
                         if (!Temp_ID.empty())
-                        {
                             Temp_ID+=__T('-');
-                            Temp_ID_String+=__T('-');
-                        }
                         Temp_ID+=Retrieve(StreamKind_Last, StreamPos_Last, General_ID);
-                        Temp_ID_String+=Retrieve(StreamKind_Last, StreamPos_Last, General_ID);
                     }
                     Fill(StreamKind_Last, StreamPos_Last, General_ID, Temp_ID, true);
-                    Fill(StreamKind_Last, StreamPos_Last, General_StreamOrder, Temp_ID_String, true);
+                    auto Temp_ID_DashPos=Temp_ID.find(__T('-'));
+                    if (Temp_ID_DashPos!=string::npos)
+                        Temp_ID.resize(Temp_ID_DashPos);
+                    Fill(StreamKind_Last, StreamPos_Last, General_StreamOrder, Temp_ID, true);
 
                     //Special case: multiple fmt/data chunks in WAV
                     if (StreamKind_Last==Stream_Audio //TODO: smarter merge
@@ -868,7 +868,12 @@ bool File_Riff::Header_Begin()
         Element_Begin1("...Continued");
         Element_ThisIsAList();
         if (Buffer_DataToParse_End)
+        {
+            Header_Fill_Code(0x64617461);
             Header_Fill_Size(Buffer_DataToParse_End-(File_Offset+Buffer_Offset));
+            if (Buffer_DataToParse_End>File_Size)
+                Buffer_DataToParse_End=File_Size; // Done here for at least one conformance check of the value. TODO: better handling
+        }
         else
             Header_Fill_Size(Element_Size);
         Element_End();
@@ -1048,6 +1053,16 @@ void File_Riff::Header_Parse()
             Size_Complete=WAVE_data_Size;
             Param_Info1(Size_Complete);
         }
+        else if (Element_Level==3) // Only the chunks directly under the main RIFF chunk
+        {
+            for (const chunk_size_64& DS64_Table_Temp : DS64_Table)
+            {
+                if (DS64_Table_Temp.ChunkId==Name) {
+                    Size_Complete=DS64_Table_Temp.Size;
+                    Param_Info1(Size_Complete);
+                }
+            }
+        }
     }
 
     //Testing malformed (not word aligned)
@@ -1079,9 +1094,8 @@ void File_Riff::Header_Parse()
     }
     if (File_Offset+Buffer_Offset+8+Size_Complete>File_Size)
     {
-        Size_Complete=File_Size-(File_Offset+Buffer_Offset+8);
         if (Element_Level<=2) //Incoherencies info only at the top level chunk
-            Fill(Stream_General, 0, "IsTruncated", "Yes");
+            IsTruncated(File_Offset+Buffer_Offset+8+Size_Complete, Element_Offset!=8, Ztring().From_CC4(Name).Trim().To_UTF8().c_str());
     }
 
     //Alignment
@@ -1096,12 +1110,15 @@ void File_Riff::Header_Parse()
     //Top level chunks
     if (Name==Elements::LIST
      || Name==Elements::RIFF
+     || Name==Elements::BW64
      || Name==Elements::RF64
      || Name==Elements::ON2_
      || Name==Elements::FORM)
     {
         if (Name==Elements::RF64)
             IsRIFF64=true;
+        if (Name==Elements::BW64)
+            IsRIFF64=IsBW64=true;
         Get_C4 (Name,                                           "Real Name");
 
         //Handling buggy files
@@ -1186,6 +1203,24 @@ bool File_Riff::BookMark_Needed()
     return true;
 }
 
+//---------------------------------------------------------------------------
+#if MEDIAINFO_CONFORMANCE
+string File_Riff::CreateElementName()
+{
+    string Result;
+    for (size_t i = 1; i < Element_Level; i++) {
+        Result += Ztring().From_CC4(Element[i].Code).Trim().To_UTF8();
+        if (Result.back() >= '0' && Result.back() <= '9') {
+            Result += '_';
+        }
+        Result += __T(' ');
+    }
+    if (!Result.empty())
+        Result.pop_back();
+    return Result;
+}
+#endif
+
 //***************************************************************************
 // Helpers
 //***************************************************************************
